#
# spec file for package neovim-gtk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define icondir %{_datadir}/icons
%define binname nvim-gtk
Name:           neovim-gtk
Version:        0.2.0+git.1609586374.c036492
Release:        6.3
Summary:        GTK UI for Neovim
License:        GPL-3.0-only
Group:          Productivity/Text/Editors
URL:            https://github.com/daa84/neovim-gtk
Source0:        neovim-gtk-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  hicolor-icon-theme
BuildRequires:  pango-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo-gobject)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(pango) >= 0.9.0

%description
GTK UI for Neovim written in Rust using gtk-rs bindings. With ligatures
support.

%prep
%autosetup -a1 -p1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
mkdir -p %{buildroot}%{_datadir}/%{binname}/
cp -p -r runtime %{buildroot}%{_datadir}/%{binname}/
install -p -m 0644 -D desktop/org.daa.NeovimGtk.desktop \
    %{buildroot}%{_datadir}/applications/org.daa.NeovimGtk.desktop
install -p -m 0644 -D desktop/org.daa.NeovimGtk_128.png \
    %{buildroot}%{icondir}/hicolor/128x128/apps/org.daa.NeovimGtk.png
install -p -m 0644 -D desktop/org.daa.NeovimGtk_48.png \
    %{buildroot}%{icondir}/hicolor/48x48/apps/org.daa.NeovimGtk.png
install -p -m 0644 -D desktop/org.daa.NeovimGtk.svg \
    %{buildroot}%{icondir}/hicolor/scalable/apps/org.daa.NeovimGtk.svg
install -p -m 0644 -D desktop/org.daa.NeovimGtk-symbolic.svg \
    %{buildroot}%{icondir}/hicolor/symbolic/apps/org.daa.NeovimGtk-symbolic.svg

install -p -m 0755 -D target/release/nvim-gtk \
    %{buildroot}%{_bindir}/nvim-gtk

rm -vf %%{buildroot}%%{_prefix}/.crates.toml

%files
%license LICENSE
%doc README.md
%{_bindir}/%{binname}
%{_datadir}/%{binname}
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/applications/org.daa.NeovimGtk.desktop

%changelog
* Tue Jun 20 2023 Martin Pluskal <mpluskal@suse.com>
- Update vendored dependencies
- Use cargo macros
* Tue Feb 14 2023 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue Apr  5 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo_vendor and cargo_audit services
* Fri Feb 12 2021 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1609586374.c036492:
  * Delete FUNDING.yml
  * Adds an option to change cursor blinking
  * Update README with Debian install instructions
  * Add support for strikethrough
  * Fix underlines/undercurl rendering
* Sat Jan 25 2020 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1579960262.0af8952:
  * fix build
  * Fix mouse selection while dragging with leftclick, fixes #185
* Wed Dec  4 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1575188169.31fd179:
  * Update text color under cursor
  * Update README.md
  * Update rust.yml
  * Create rust.yml
  * Major update of dependencies
  * Cleanup
  * Create FUNDING.yml
  * Update README.md
  * Fix background rendering (#208)
  * Use f64 instead of i32 for width caulculation (#208)
  * Try to fix render issues due to changes in pango_1.44 (#208)
* Sun Nov 24 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1570090897.3ace1d2:
  * Fix the logic error
  * Update dependencies
  * Update Rust to 1.38 for AppVeyor
  * Clippy fixes
* Wed Jul 17 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1563130800.6b0687d:
  * Add the username to logname
* Mon Jul  8 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1562530001.44982f9:
  * Explicit `dyn` for trait objects
  * Update dependencies
* Mon May 27 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1558343550.dfb97c8:
  * Add openSUSE link from #160
* Sun May 19 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1557694118.1b89b26:
  * Expand tabs to fill tabline
* Sat May 11 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1557330294.f3aa855:
  * Update README.md
* Wed May  8 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.2.0+git.1556702287.3c5d6e8:
  * Create CHANGELOG.md
  * Termcolors
  * Fix install script
  * Migration to rust 2018 edition
  * Migrate to new gtk version
  * Extract function
  * Load file after all initialization complete
  * Use git describe version (fix #191)
  * Remove enable-swap option (fix #150)
  * Space render optimization
  * Small optimization
  * Fix crash (#179)
  * Update rustc version
  * Fix model update bug
  * Cleanup
  * Use new hl api to get theme colors
  * Use fnv hasher
  * Update minimum supported version
  * Fix test
  * Use HighlightMap in cmdline
  * Update cmdline API
  * Cleanup
  * Fix highlits
  * Fix tests build
  * Fix scroll
  * Yeah, now it starts
  * Update internal api to use new methods
  * Highlight api
  * grid resize/default colors set
  * grid scroll
  * Some new grid events
  * implement grid_line call
* Sat Apr 20 2019 Matej Cepl <mcepl@suse.com>
- Fix %%prep section: remove unnecessary double extraction of
  tarballs, and use %%autopatch instead of %%autosetup.
* Mon Apr 15 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.1.2~git.1555146623.8d26c90:
  * New command ShowProjectView #189
* Mon Apr  8 2019 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.1.2~git.1553003517.c8b11cb:
  * Update used Rust version for AppVeyor
  * Update dependencies
  * Fix .trim_right_matches() -> .trim_end_matches()
* Sun Feb 17 2019 opensuse-packaging@opensuse.org
- Update to version 0.1.2~git.1550348053.c075c32:
  * Add the most recent versions of gio, cairo, and glib crates.
- Remove fix_dependencies.patch, accepted upstream.
* Fri Feb  8 2019 Matej Cepl <mcepl@suse.com>
- Upgrade Gnome libraries
* Fri Jan 25 2019 opensuse-packaging@opensuse.org
- Update to version 0.1.2~git.1548079905.6c3af02:
  * Extract draw cursor to function
  * Fix subpixel font rendering
* Sun Jan 20 2019 opensuse-packaging@opensuse.org
- Update to version 0.1.2~git.1548079905.6c3af02:
  * Extract draw cursor to function
  * Fix subpixel font rendering
  * Wrong itemize split must not crash application (fix #170)
* Wed Jan 16 2019 Matěj Cepl <mcepl@suse.com>
- /usr/bin/nvim-gtk should certainly be executable.
* Fri Jan 11 2019 opensuse-packaging@opensuse.org
- Update to version 0.1.2~git.1546506277.7cda84c:
  * Don't use -i option for sed to make it more compatible with non-GNU sed.
* Fri Dec 21 2018 opensuse-packaging@opensuse.org
- Update to version 0.1.2~git.1544347959.a440248:
  * Add completeopt preview option support #162, #34
  * Add Gitter badge
  * Add patterns to event subscriptions and test with settable title prefix
* Sun Nov 25 2018 opensuse-packaging@opensuse.org
- Update to version 0.1.2~git.1542529989.828a78b:
  * Code cleanup
  * Migrate all arguments
  * Parse command line with clap.
* Fri Nov 16 2018 opensuse-packaging@opensuse.org
- Update to version 0.1.2~git.1541923441.011c1d5:
  * Correct symbolic version of the icon
  * Added option --enable-swap (#150)
  * Split font names by comma and use existing (fixes #158)
  * No warning on empty font
  * Change colors in design-file of symbolic icon
  * Correct icons file renaming in Makefile
  * Correct transparency on symbolic icon
  * Add symbolic versioned icon for GNOME's top-bar
* Fri Nov 16 2018 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for neovim-gtk 0.1.1
